BuildInfo

Struct BuildInfo 

pub struct BuildInfo {
    pub version: &'static str,
    pub sha: &'static str,
}
Build information.

Fields

version: &'static str

The version number of the build.

sha: &'static str

The 40-character SHA-1 hash identifying the Git commit of the build.

Implementations

Source

impl BuildInfo

pub fn human_version(&self, helm_chart_version: Option<String>) -> String

Constructs a human-readable version string.

pub fn semver_version(&self) -> Version

Returns the version as a rich semantic version.

This method is only available when the semver feature is active.

Panics

Panics if the version field is not a valid semantic version.

pub fn semver_version_build(&self) -> Option<Version>

The same as Self::semver_version, but includes build metadata in the returned version, if build metadata is available on the compiled platform.

pub fn version_num(&self) -> i32

Returns the version as an integer along the lines of Pg’s server_version_num

pub fn is_dev(&self) -> bool

Returns whether the version is a development version